@@ -55,7 +55,6 @@ DesktopGridEffect::DesktopGridEffect()
     , wasDesktopMove(false)
     , isValidMove(false)
     , windowMove(NULL)
-    , m_highlightWindow(nullptr)
     , windowMoveDiff()
     , gridSize()
     , orientation(Qt::Horizontal)
@@ -284,14 +283,8 @@ void DesktopGridEffect::paintWindow(EffectWindow* w, int mask, QRegion region, W
             }
         }
 
-        const bool isOnThisDesktop = !w->isOnAllDesktops() || paintingDesktop == highlightedDesktop;
-        const bool zoom = w == m_highlightWindow  && isOnThisDesktop;
         qreal xScale = data.xScale();
         qreal yScale = data.yScale();
-        if (zoom) {
-            xScale *= 1.05f;
-            yScale *= 1.05f;
-        }
 
         data.multiplyBrightness(1.0 - (0.3 * (1.0 - hoverTimeline[paintingDesktop - 1]->currentValue())));
 
@@ -316,10 +309,6 @@ void DesktopGridEffect::paintWindow(EffectWindow* w, int mask, QRegion region, W
                 if (w->isDesktop())
                     quadsAdded = false;
             }
-            if (zoom) {
-                transformedGeo.translate(-0.025f*transformedGeo.width(),
-                                         -0.025f*transformedGeo.height());
-            }
             if (!quadsAdded) {
                 foreach (const WindowQuad & quad, data.quads) {
                     QRect quadRect(
@@ -466,14 +455,6 @@ void DesktopGridEffect::windowInputMouseEvent(QEvent* e)
 
     if (e->type() == QEvent::MouseMove) {
         int d = posToDesktop(me->pos());
-        if (!(wasDesktopMove || wasWindowMove)) {
-            EffectWindow *oldHighlightWindow = m_highlightWindow;
-            m_highlightWindow = windowAt(me->pos());
-            if (m_highlightWindow && m_highlightWindow->isDesktop())
-                m_highlightWindow = nullptr;
-            if (oldHighlightWindow != m_highlightWindow)
-                effects->addRepaintFull();
-        }
         if (windowMove != NULL &&
                 (me->pos() - dragStartPos).manhattanLength() > QApplication::startDragDistance()) {
             // Handle window moving
