@@ -23,8 +23,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QAction>
 #include <QObject>
 #include <QPoint>
+#include <QPointer>
 #include <config-kwin.h>
 
+#include <KSharedConfig>
+
 class KGlobalAccelInterface;
 class QKeySequence;
 class QMouseEvent;
@@ -40,6 +43,11 @@ class KeyboardInputRedirection;
 class PointerInputRedirection;
 class TouchInputRedirection;
 
+namespace Decoration
+{
+class DecoratedClientImpl;
+}
+
 namespace LibInput
 {
     class Connection;
@@ -212,6 +220,7 @@ private:
     LibInput::Connection *m_libInput = nullptr;
 
     QVector<InputEventFilter*> m_filters;
+    KSharedConfigPtr m_inputConfig;
 
     KWIN_SINGLETON(InputRedirection)
     friend InputRedirection *input();
@@ -277,6 +286,42 @@ public:
     virtual bool touchUp(quint32 id, quint32 time);
 };
 
+class InputDeviceHandler : public QObject
+{
+    Q_OBJECT
+public:
+    virtual ~InputDeviceHandler();
+
+    QPointer<Toplevel> window() const {
+        return m_window;
+    }
+    QPointer<Decoration::DecoratedClientImpl> decoration() const {
+        return m_decoration;
+    }
+    QPointer<QWindow> internalWindow() const {
+        return m_internalWindow;
+    }
+
+Q_SIGNALS:
+    void decorationChanged();
+    void internalWindowChanged();
+
+protected:
+    explicit InputDeviceHandler(InputRedirection *parent);
+    void updateDecoration(Toplevel *t, const QPointF &pos);
+    void updateInternalWindow(const QPointF &pos);
+    InputRedirection *m_input;
+    /**
+     * @brief The Toplevel which currently receives events
+     */
+    QPointer<Toplevel> m_window;
+    /**
+     * @brief The Decoration which currently receives events.
+     **/
+    QPointer<Decoration::DecoratedClientImpl> m_decoration;
+    QPointer<QWindow> m_internalWindow;
+};
+
 inline
 InputRedirection *input()
 {
