@@ -26,6 +26,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // KWin libs
 #include <kwinxrenderutils.h>
 #include "workspace.h"
+// Frameworks
+#include <KConfigGroup>
 // Qt
 #include <QDebug>
 #include <QQmlComponent>
@@ -150,8 +152,8 @@ void CompositedOutlineVisual::show()
     }
     if (m_qmlComponent.isNull()) {
         m_qmlComponent.reset(new QQmlComponent(Scripting::self()->qmlEngine()));
-        // TODO: fileName should be configurable
-        const QString fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral(KWIN_NAME "/outline/plasma/outline.qml"));
+        const QString fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
+                                                 kwinApp()->config()->group(QStringLiteral("Outline")).readEntry("QmlPath", QStringLiteral(KWIN_NAME "/outline/plasma/outline.qml")));
         if (fileName.isEmpty()) {
             qCDebug(KWIN_CORE) << "Could not locate outline.qml";
             return;
