@@ -537,12 +537,6 @@ void Scene::Window::suspendUnredirect(bool suspend)
     toplevel->suspendUnredirect(suspend);
 }
 
-inline
-void Scene::Window::updateShadow(Shadow* shadow)
-{
-    m_shadow = shadow;
-}
-
 inline
 const Shadow* Scene::Window::shadow() const
 {
